#Setting the working directory ----
#(so R knows where to look for data and save files)

setwd("where your data is")

#Installing and loading the necessary packages ----
#(so R can access the any additional functions needed for the next steps)

library(readr) #for read_tsv() ~ tab deliminated data
library(dplyr) #for creating statistical summaries
library(ggplot2) #for creating plots 
library(tidyr) #for pivot_longer()
#Note, we can also use library(tidyverse) to load these

#Importing, exploring and cleaning the data ----
#(to get the data in R an make sure the data is error free for analysis)

#import the data - note read_tsv() is used as values
#are tab seperated values 
random_data<-read_tsv("some dataset.tsv")

 
#plot the data to see what it looks like
plot(random_data$x,random_data$y)

#or using ggplot2: 
ggplot(data=random_data, aes(x=x,y=y)) +
  geom_point()



#Create a statistical summary to compare datasets
summary<-random_data %>% group_by(group) %>% 
  summarise(n=n(),
            mean_x=mean(x),
            mean_y=mean(y),
            sd_x=sd(x),
            sd_y=sd(y))

#reshape the summary to allow easy plotting 
summary_long<- summary %>% 
  pivot_longer(cols=-group)

#create a barplot of statistics
ggplot(data= summary_long,aes(x=group,y=value)) +
  geom_bar(stat="identity") +
  facet_grid(. ~ name)

#summary statistics are almost identical, but notice n
#looking at the data it appears that groups may have 
#been mislabeled from row 853 to 994. 
#We can correct this using: 

random_data$group[853:994]<-7


#there appears to be subtle differences, but the
#summary stats are very similar 
#what if we colour the points by the group?
ggplot(data=random_data, aes(x=x,y=y,colour=group)) +
  geom_point()

 
#still confusing, there is a lot of noise. How about
#we use separate plots according to group using facets?

ggplot(data=random_data, aes(x=x,y=y,colour=group)) +
  geom_point() + 
  facet_grid(group ~ .)

#facets creates separate scatter plots by 'group' 
#Although it's messy, if you click 'zoom' in Rstudio
#You can change the scales of the plot to show how
#different each dataset is despite having similar 
#summary statistics. 
#This is a good reason to look at the data :)
#Data Source: https://cran.r-project.org/web/packages/datasauRus/vignettes/Datasaurus.html


#Summarizing and analysing the data ----
#(to answer the questions we want to pose)


#Saving the results ----
#(to present to others and add to other documents)